@@ -2,12 +2,6 @@ import argparse
 import logging
 from ..system import setup_startup
 
-from .cameraserver import CameraServer
-from .ioserver import IOServer
-from .advertising import AdvertisingServer
-
-
-
 def run():
     parser = argparse.ArgumentParser(
         description='Start the Engage eduROV web server')
@@ -43,7 +37,7 @@ def run():
     parser.add_argument(
         '--runatstartup',
         action='store_true',
-        help='Setup server to run at startup and exit program.')
+        help='Setup server to run at startup and exit program. Must be run as sudo')
 
     args = parser.parse_args()
 
@@ -52,8 +46,16 @@ def run():
         setup_startup()
         return
 
+    from .cameraserver import CameraServer
+    from .ioserver import IOServer
+    from .advertising import AdvertisingServer, wait_until_available
+
     logging.basicConfig(level=args.loglevel)
 
+    wait_until_available()
+
+    logging.info("Network service is available, starting servers.")
+
     ioserver = IOServer(args.serial, loglevel=args.loglevel)
     camera = CameraServer(args.r, args.fps, args.loglevel)
     advertisingserver = AdvertisingServer(loglevel=args.loglevel)
